@@ -10,5 +10,8 @@ class OkErrorCodeAndMessageResult(ResultBase):
         if self.success is True:
             return
 
+        if "message" in result:
+            self.message = result["message"]
+
         if "errorCode" in result:
             self.message = self.getMessageForErrorCode(self.message, result["errorCode"])
\ No newline at end of file
